@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-06-08'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [any => {
     summary => 'String or array (1+ length) of (defined) string',
@@ -41,20 +41,72 @@ Sah::Schema::str_or_aos1 - String or array (1+ length) of (defined) string
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::str_or_aos1 (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
+This document describes version 0.006 of Sah::Schema::str_or_aos1 (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
 
 =head1 SYNOPSIS
 
+=head2 Sample data and validation results against this schema
+
+ ""  # valid
+
+ "a"  # valid
+
+ {}  # INVALID (Not string or array)
+
+ []  # INVALID (Empty array)
+
+ ["a"]  # valid
+
+ ["a",undef]  # INVALID (Has undef element)
+
+ ["a",[]]  # INVALID (Has non-string element)
+
+=head2 Using with Data::Sah
+
 To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
  my $validator = gen_validator("str_or_aos1*");
  say $validator->($data) ? "valid" : "INVALID!";
 
- # Data::Sah can also create validator that returns nice error message string
- # and/or coerced value. Data::Sah can even create validator that targets other
- # language, like JavaScript. All from the same schema. See its documentation
- # for more details.
+The above schema returns a boolean result (true if data is valid, false if
+otherwise). To return an error message string instead (empty string if data is
+valid, a non-empty error message otherwise):
+
+ my $validator = gen_validator("str_or_aos1", {return_type=>'str_errmsg'});
+ my $errmsg = $validator->($data);
+ 
+ # a sample valid data
+ $data = "";
+ my $errmsg = $validator->($data); # => ""
+ 
+ # a sample invalid data
+ $data = ["a",[]];
+ my $errmsg = $validator->($data); # => "Not of type text"
+
+Often a schema has coercion rule or default value, so after validation the
+validated value is different. To return the validated (set-as-default, coerced,
+prefiltered) value:
+
+ my $validator = gen_validator("str_or_aos1", {return_type=>'str_errmsg+val'});
+ my $res = $validator->($data); # [$errmsg, $validated_val]
+ 
+ # a sample valid data
+ $data = "";
+ my $res = $validator->($data); # => ["",""]
+ 
+ # a sample invalid data
+ $data = ["a",[]];
+ my $res = $validator->($data); # => ["Not of type text",["a",[]]]
+
+Data::Sah can also create validator that returns a hash of detailed error
+message. Data::Sah can even create validator that targets other language, like
+JavaScript, from the same schema. Other things Data::Sah can do: show source
+code for validator, generate a validator code with debug comments and/or log
+statements, generate human text from schema. See its documentation for more
+details.
+
+=head2 Using with Params::Sah
 
 To validate function parameters against this schema (requires L<Params::Sah>):
 
@@ -67,11 +119,14 @@ To validate function parameters against this schema (requires L<Params::Sah>):
      ...
  }
 
+=head2 Using with Perinci::CmdLine::Lite
+
 To specify schema in L<Rinci> function metadata and use the metadata with
-L<Perinci::CmdLine> to create a CLI:
+L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
  # in lib/MyApp.pm
- package MyApp;
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -91,9 +146,10 @@ L<Perinci::CmdLine> to create a CLI:
  1;
 
  # in myapp.pl
- package main;
+ package
+   main;
  use Perinci::CmdLine::Any;
- Perinci::CmdLine::Any->new(url=>'MyApp::myfunc')->run;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
 
  # in command-line
  % ./myapp.pl --help
@@ -104,22 +160,6 @@ L<Perinci::CmdLine> to create a CLI:
 
  % ./myapp.pl --arg1 ...
 
-Sample data:
-
- ""  # valid
-
- "a"  # valid
-
- {}  # INVALID (Not string or array)
-
- []  # INVALID (Empty array)
-
- ["a"]  # valid
-
- ["a",undef]  # INVALID (Has undef element)
-
- ["a",[]]  # INVALID (Has non-string element)
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Str>.
