@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-06-08'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 1;
 # ABSTRACT: Various string schemas
@@ -22,10 +22,12 @@ Sah::Schemas::Str - Various string schemas
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
+This document describes version 0.006 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
 
 =head1 SAH SCHEMAS
 
+The following schemas are included in this distribution:
+
 =over
 
 =item * L<hexstr|Sah::Schema::hexstr>
@@ -74,9 +76,9 @@ Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Str>.
 
 =head1 SEE ALSO
 
-L<Sah> - specification
+L<Sah> - schema specification
 
-L<Data::Sah>
+L<Data::Sah> - Perl implementation of Sah
 
 =head1 AUTHOR
 
